local sti = require 'libs/sti'
local bump = require 'libs/bump/bump'
local scale = 2.5
local message = ''

local player = {}

local player = {x = 50,
                lastY = 50,
                y = 50,
                w = 32,
                h = 32,
                speed = 0.85,
                yAcc = 0,
                xAcc = 0,
                vel = 4,
                states = {grounded = 'I am on the ground',
                    jumping = 'I am jumping',
                    falling = 'I am falling'},
                dx = 0,
                dy = 0,
                maxJump = 10,
                jumpTimer = 0
}

local world = bump.newWorld(32)

function love.load()
    -- uncomment the line below if using zerobrane debugging (http://notebook.kulchenko.com/zerobrane/love2d-debugging)
    -- if arg[#arg] == "-debug" then require("mobdebug").start() end

    map = sti('assets/maps/mymap.lua', {'bump'})
    map:bump_init(world)

    player.currentState = player.states['grounded'],

    world:add(player, player.x, player.y, player.w, player.h)
end

function love.update(dt)
    map:update(dt)

    player.lastY = player.y

    player.yAcc = 1
    player.dx = 0

    if love.keyboard.isDown('left') then player.xAcc = -player.speed end
    if love.keyboard.isDown('right') then player.xAcc = player.speed end
    if love.keyboard.isDown('up') and player.currentState == player.states['grounded'] then
        player.currentState = player.states['jumping']
        player.jumpTimer = player.maxJump
    end

    if player.currentState == player.states['jumping'] then
        player.jumpTimer = player.jumpTimer - 1
        player.yAcc = -2
        if player.jumpTimer <= 0 then
            player.currentState = player.states['falling']
        end
    end

    player.dx = player.xAcc * player.vel
    player.dy = player.yAcc * player.vel

    player.x, player.y, cols, len = world:move(player, player.x + player.dx, player.y + player.dy)

    player.xAcc, player.yAcc = 0, player.yAcc * 0.45

    if len ~= 0 then
        for i = 1, len do
            _, _, tcols, tlen = world:check(player, player.x, cols[i].touch.y - 2)
            _, _, bcols, blen = world:check(player, player.x, cols[i].touch.y + 2)
            if blen ~= 0 then collisionSide = 'floor'
            elseif tlen ~= 0 then collisionSide = 'ceiling'
            end
        end
    end

    if player.lastY == player.y and collisionSide == 'floor' then player.currentState = player.states['grounded'] end
end

function love.draw()
    love.graphics.print(player.currentState, 0, 0)

    dx = player.x - (love.graphics.getWidth() / 2) / scale
    dy = player.y - (love.graphics.getHeight() / 2) / scale

    love.graphics.scale(scale)
    love.graphics.translate(-dx, -dy)

    map:draw(-dx, -dy, scale, scale)

    love.graphics.rectangle('fill', player.x, player.y, player.w, player.h)
end
